sequencetools.partition_sequence_cyclically_by_weights_exactly_without_overhang
===============================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_cyclically_by_weights_exactly_without_overhang.partition_sequence_cyclically_by_weights_exactly_without_overhang
